==> unforward-0.1.1.tar.gz: unforward-0.1.1/unforward/test/examples.py <==
#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

examples =  [
                {
                    "client": ["outlook", "iphone"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/outlook_express_forward.html",
                    "result" : {'sender' : 'laolaw@lao.on.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/google_forward.html",
                    "result" : {'sender' : 'jamie@moonrider.com',
                                'body'   : '<p> Original Email</p>'}
                },
                {
                    "client": ["blackberry"],
                    "file" : "examples/blackberry_forward.html",
                    "result" : {'sender' : 'efenkell@gmail.com',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["iphone", "outlook"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/iphone_forward.html",
                    "result" : {'sender' : 'dmz@ryerson.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["lotusnotes"],
                    "file" : "examples/lotus_notes_forward.txt",
                    "result" : {'sender' : 'jamie@getsensibill.com',
                                'body'   : 'Original Email'}
                },
                {
                    "client": ["yahoo"],
                    "file" : "examples/yahoo_forward.html",
                    "result" : {'sender' : 'noreply@3scale.net',
                                'body'   : '<p> Original Email</p>'}
                }
            ]

==> unforward-0.1.3.tar.gz: unforward-0.1.3/unforward/test/examples.py <==
#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

examples =  [
                {
                    "client": ["outlook", "iphone"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/outlook_express_forward.html",
                    "result" : {'sender' : 'laolaw@lao.on.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/gmail_forward_1.html",
                    "result" : {'sender' : 'jamie@moonrider.com',
                                'body'   : '<p> Original Email</p>'}
                },
                {
                    "client": ["blackberry"],
                    "file" : "examples/blackberry_forward.html",
                    "result" : {'sender' : 'efenkell@gmail.com',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["iphone", "outlook"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/iphone_forward.html",
                    "result" : {'sender' : 'dmz@ryerson.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["lotusnotes"],
                    "file" : "examples/lotus_notes_forward.txt",
                    "result" : {'sender' : 'jamie@getsensibill.com',
                                'body'   : 'Original Email'}
                },
                {
                    "client": ["yahoo"],
                    "file" : "examples/yahoo_forward.html",
                    "result" : {'sender' : 'noreply@3scale.net',
                                'body'   : '<p> Original Email</p>'}
                }
            ]
